@@ -7,12 +7,12 @@ use Class::Load qw/ load_class /;
 use Class::Accessor::Lite::Lazy (
     new     => 1,
     rw      => [qw/ team_domain token opt /],
-    ro_lazy => [qw/ client api auth channels chat dialog emoji files groups im oauth pins reactions rtm search stars team users /],
+    ro_lazy => [qw/ client api auth channels conversations chat dialog emoji files groups im oauth pins reactions rtm search stars team users dnd /],
 );
 
 use WebService::Slack::WebApi::Client;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub _build_client {
     my $self = shift;
@@ -23,7 +23,7 @@ sub _build_client {
     );
 }
 
-for my $class_name (qw/ api auth channels chat dialog emoji files groups im oauth pins reactions rtm search stars team users /) {
+for my $class_name (qw/ api auth channels conversations chat dialog emoji files groups im oauth pins reactions rtm search stars team users dnd /) {
     my $method = sprintf '%s::_build_%s', __PACKAGE__, $class_name;
     my $class  = sprintf '%s::%s', __PACKAGE__, ucfirst($class_name);
 
